==> haskell-test-framework-quickcheck2-0.3.0.6-153-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-quickcheck2
version:              0.3.0.6
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.6-8bMqeZqXlyR86Cdp0060WK
key:                  test-framework-quickcheck2-0.3.0.6-8bMqeZqXlyR86Cdp0060WK
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  0fa9ccc2b4d828262e68ed5fc738c38d
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-quickcheck2
hs-libraries:         HStest-framework-quickcheck2-0.3.0.6-8bMqeZqXlyR86Cdp0060WK
depends:
    QuickCheck-2.14.3-6LKdi6bmSSC7fWzYy22Dkb base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    random-1.2.1.3-FtBkzNFMEVVAWMk0jeYogw
    test-framework-0.8.2.2-7ahRZRaZ9AJ8o3cXYokX9z

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-quickcheck2-0.3.0.6-154-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-quickcheck2
version:              0.3.0.6
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.6-JwzqHQ7N0pvFOd0JT5tEOg
key:                  test-framework-quickcheck2-0.3.0.6-JwzqHQ7N0pvFOd0JT5tEOg
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  e0cd33ee183357cb8dc4de6a36dd9974
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-quickcheck2
hs-libraries:         HStest-framework-quickcheck2-0.3.0.6-JwzqHQ7N0pvFOd0JT5tEOg
depends:
    QuickCheck-2.14.3-6LKdi6bmSSC7fWzYy22Dkb base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    random-1.2.1.3-FtBkzNFMEVVAWMk0jeYogw
    test-framework-0.8.2.2-2iDinLh1Rum5bVTmfAeycj

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
